@@ -182,7 +182,10 @@ class CfLogSqliteModel(CfLogSqliteConnection):
 
         logger.debug(sql)
         result = self.execute(sql)
-        return result
+        if result is None:
+            return []
+        else:
+            return result
 
     def write_kwargs(self, pk=None, **kwargs) -> int:
         """Insert record into database from keyword arguments.
